@@ -113,8 +113,7 @@ def rho2rho(eqm, rho_in, t_in=None, \
     else:
         raise Exception('unsupported output coordinate')
 
-    jcoco = eqm.cocos%10 - 1
-    psi_sign = -eqm.orientation*cocos.sigma['bp'][jcoco]
+    psi_sign = np.sign(eqm.psi_fac)
     PFL  = psi_sign*eqm.pfl
     PSIX = psi_sign*eqm.psix
     PSI0 = psi_sign*eqm.psi0
@@ -124,16 +123,12 @@ def rho2rho(eqm, rho_in, t_in=None, \
   
 # Calculate a normalized input and output flux 
 
-#        fout = interp1d(PFL[i], label_out[i], fill_value="extrapolate")
-#        (sep_out, mag_out) = fout([PSIX[i], PSI0[i]])
         mag_out, sep_out = np.interp([PSI0[i], PSIX[i]],  PFL[i], label_out[i])
         if lbl_in != lbl_out:
-#            fin  = interp1d(PFL[i], label_in[i] , fill_value="extrapolate")
-#            (sep_in , mag_in ) = fin( [PSIX[i], PSI0[i]])
             mag_in, sep_in = np.interp([PSI0[i], PSIX[i]],  PFL[i], label_in[i])
         else:
-            sep_in = sep_out
             mag_in = mag_out
+            sep_in = sep_out
 
         if (abs(sep_out - mag_out) < 1e-4) or (abs(sep_in - mag_in) < 1e-4): #corrupted timepoint
             continue
@@ -249,20 +244,6 @@ def rz2brzt(eqm, r_in, z_in, t_in=None):
     dr = (eqm.Rmesh[-1] - eqm.Rmesh[0])/float(nr - 1)
     dz = (eqm.Zmesh[-1] - eqm.Zmesh[0])/float(nz - 1)
 
-# COCOS, Eq. 19, 24
-    cocos_in = eqm.cocos
-    jcoco    = cocos_in%10 - 1
-    ebp_in   = cocos_in//10
-    sign_ip  = np.sign(np.nanmean(eqm.ipipsi))
-    sign_b0  = np.sign(np.nanmean(eqm.jpol))
-    sigma_ip = sign_ip*cocos.sigma['rphiz'][jcoco]
-    sigma_b0 = sign_b0*cocos.sigma['rphiz'][jcoco]
-    phi_sign = sigma_b0
-    psi_sign = sigma_ip*cocos.sigma['bp'][jcoco]
-    psi_2pi  = (2.*np.pi)**ebp_in
-    psi_fac = psi_sign*psi_2pi
-    logger.debug('COCOS %d, Sign Bt %d, Sign Ip %d' %(cocos_in, sign_b0, sign_ip))
-
     unique_idx, index_idx =  get_nearest_index(eqm.time, tarr)
 
     for i in unique_idx:
@@ -282,9 +263,9 @@ def rz2brzt(eqm, r_in, z_in, t_in=None):
         interpBz[jt] = f_bz(r, z, grid=False)
         interpBt[jt] = f_bt(r, z, grid=False)
 
-    return interpBr/(psi_fac*dz), \
-           interpBz/(psi_fac*dr), \
-           np.abs(interpBt)/psi_2pi * phi_sign
+    return interpBr/(eqm.psi_fac*dz), \
+           interpBz/(eqm.psi_fac*dr), \
+           interpBt/np.abs(eqm.psi_fac) * eqm.phi_sign
 
 
 def Bmesh(eqm, t_in=None):
@@ -321,20 +302,6 @@ def Bmesh(eqm, t_in=None):
     dr = (eqm.Rmesh[-1] - eqm.Rmesh[0])/float(nr - 1)
     dz = (eqm.Zmesh[-1] - eqm.Zmesh[0])/float(nz - 1)
 
-# COCOS, Eq. 24
-    cocos_in = eqm.cocos
-    jcoco    = cocos_in%10 - 1
-    ebp_in   = cocos_in//10
-    sign_ip  =  eqm.orientation
-    sign_b0  = -eqm.orientation
-    sigma_ip = sign_ip*cocos.sigma['rphiz'][jcoco]
-    sigma_b0 = sign_b0*cocos.sigma['rphiz'][jcoco]
-    phi_sign = sigma_b0
-    psi_sign = cocos.sigma['bp'][jcoco]
-    psi_2pi  = (2.*np.pi)**ebp_in
-    psi_fac = psi_sign*psi_2pi
-    logger.info('COCOS %d' %cocos_in)
-
     unique_idx, index_idx =  get_nearest_index(eqm.time, tarr)
 
     Br = np.zeros((nt, nr, nz), dtype=np.float32)
@@ -350,9 +317,9 @@ def Bmesh(eqm, t_in=None):
         fBt = interp1d(eqm.pfl[i], eqm.jpol[i], kind='linear', fill_value='extrapolate')
         Bt[jt] = fBt(Psi)*mu_0/eqm.Rmesh[:, None]
 
-    return Br/(psi_fac*dz), \
-           Bz/(psi_fac*dr), \
-           Bt/psi_2pi * phi_sign
+    return Br/(eqm.psi_fac*dz), \
+           Bz/(eqm.psi_fac*dr), \
+           Bt/np.abs(eqm.psi_fac) * eqm.phi_sign
 
 
 def rz2rho(eqm, r_in, z_in, t_in=None, coord_out='rho_pol', extrapolate=True):
@@ -709,8 +676,8 @@ def rhoTheta2rz(eqm, rho, theta_in, t_in=None, coord_in='rho_pol', n_line=201):
     jcoco = eqm.cocos%10 - 1
     if coord_in == 'Psi':
         rho_line[:,:,0] = eqm.psi0[unique_idx][:,None]
-        rho_line *= -eqm.orientation*cocos.sigma['bp'][jcoco]
-        rho      *= -eqm.orientation*cocos.sigma['bp'][jcoco]
+        rho_line *= -eqm.ip_ccw*cocos.sigma['bp'][jcoco]
+        rho      *= -eqm.ip_ccw*cocos.sigma['bp'][jcoco]
     else:
         #solve some issues very close to the core
         rho_line[:,:,0] = 0
@@ -880,6 +847,8 @@ def to_geqdsk(eqm, t_in=0.):
     
     # separatrix R and Z
     geq['RBBBS'], geq['ZBBBS'] = rho2rz(equ, 0.999, t_in=equ.time[jt], all_lines=False)
+    geq['RBBBS'] = geq['RBBBS'][0][0]
+    geq['ZBBBS'] = geq['ZBBBS'][0][0]
 
     # R,Z of limiter structures
     geq['RLIM'] = [1.035, 1.050, 1.090, 1.140, 1.235, 1.340, 1.430, 1.505, 1.630, 1.770, 1.970, 2.110, 2.170, 2.205, 2.210, 2.175, 2.130, 2.010, 1.890, 1.705, 1.645, 1.580, 1.458, 1.325, 1.235, 1.286, 1.280, 1.245, 1.125, 1.060, 1.035]
@@ -900,7 +869,7 @@ def to_geqdsk(eqm, t_in=0.):
     geq['BCENTR']  = equ.B0[jt]
     geq['RCENTR']  = equ.R0  ##[jt]   # TODO this seems to be time-independent?
     geq['ZMID']    = 0.5*(equ.Zmesh[-1] + equ.Zmesh[0])
-    geq['PSIRZ']   = equ.pfm[:, :, jt]
+    geq['PSIRZ']   = equ.pfm[:, :, jt].T
 
     # Interpolate onto an equidistant Psi-grid
     psi_grid = np.linspace(psi_in[0], psi_in[-1], len(equ.Rmesh))
