@@ -4,7 +4,7 @@ import logging
 import numpy as np
 from scipy.integrate import cumtrapz
 
-from aug_sfutils import sfobj, SFREAD, parse_kwargs
+from aug_sfutils import sfobj, SFREAD, parse_kwargs, cocos
 
 logger = logging.getLogger('aug_sfutils.sf2equ')
 
@@ -91,7 +91,18 @@ class EQU:
         logger.info('Reading equ PFM')
         self.read_pfm()
 
-        logger.info('Detected COCO %d' %self.cocos)
+        logger.info('COCO %d' %self.cocos)
+
+# Sign of Ip, Bt (positive=ccw from above), valid for COCOS=17 (CLISTE)
+        self.ip_ccw = np.sign((self.psix - self.psi0).mean())
+        self.bt_ccw = np.sign(np.nanmean(self.jpol))
+
+        jcoco = self.cocos%10 - 1
+        ebp   = self.cocos//10
+        psi_sign = -self.ip_ccw*cocos.sigma['bp'][jcoco]*cocos.sigma['rphiz'][jcoco]
+        psi_2pi  = (2.*np.pi)**ebp
+        self.psi_fac = psi_sign*psi_2pi
+        self.phi_sign = self.bt_ccw*cocos.sigma['rphiz'][jcoco]
 
         if 'tbeg' in kwargs.keys():
             tbeg = kwargs['tbeg']
@@ -210,13 +221,12 @@ class EQU:
         PFxx = self.sf.getobject('PFxx')[:, :nt]
         ikCAT = np.argmin(abs(PFxx[1:, :] - PFxx[0, :]), axis=0) + 1
         if all(PFxx[2]) == 0: ikCAT[:] = 1  #troubles with TRE equilibrium 
-        ## Sign of plasma current (positive=ccw from above)
-        self.orientation = np.sign((PFxx[1:] - PFxx[0]).mean())  #current orientation
 
         ## Poloidal flux at magnetic axis [Vs]
         self.psi0 = PFxx[0, :nt]
         ## Poloidal flux at separatrix [Vs]
         self.psix = PFxx[ikCAT, np.arange(nt)]
+
         try:
             ## Plasma current[A]
             self.ipipsi = self.sf.getobject('IpiPSI')[:nt]
