@@ -302,7 +302,7 @@ class SFREAD:
                     if self.diag in ('DCN', 'DCK', 'DCR'):
                         dout.phys_unit = '1/m^2'
             if copy and (not dout.calib):
-                dout = dout*1 # create a copy of the read-only array
+                dout = dout.copy() # create a copy of the read-only array
 
         return dout
 
@@ -432,10 +432,13 @@ class SFREAD:
             pname = str_byt.to_str(buf[j0: j0+8])
             unit, dfmt, n_items = unpack('>3h', buf[j0+8:  j0+14])
             meta = type('', (), {})()
-#            meta.phys_unit = sfdics.unit_d[unit]
+            meta.physunit = unit
+            if unit in sfdics.unit_d.keys():
+                meta.phys_unit = sfdics.unit_d[unit]
+            meta.n_items = n_items
             meta.data_format = dfmt
-            status = unpack('>h', buf[j0+14:  j0+16])[0]
-            logger.debug('PN: %s, j0: %d, unit: %d dfmt: %d n_items: %d, status: %d', pname, j0, unit, dfmt, n_items, status)
+            meta.status = unpack('>h', buf[j0+14:  j0+16])[0]
+            logger.debug('PN: %s, j0: %d, unit: %d dfmt: %d n_items: %d, status: %d', pname, j0, unit, dfmt, n_items, meta.status)
             j0 += 16
 
             if dfmt in sfdics.fmt2len.keys(): # char variable
@@ -451,7 +454,7 @@ class SFREAD:
                 if dfmt == 7: # logical, bug if n_items > 1?
                     data = unpack(sfmt, buf[j0+5: j0+6])[0]
                 else:
-                    data = np.ndarray((val_len, ), '>%s' %sfmt, buf[j0: j0+bytlen], order='F')
+                    data = np.ndarray((val_len, ), '>%s' %sfmt, buf[j0: j0+bytlen], order='F').copy()
                     data = np.squeeze(data[2:])
                 dj0 = 8 * ( (bytlen + 7)//8 )
                 j0 += dj0
